(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     95795,       1965]
NotebookOptionsPosition[     91343,       1897]
NotebookOutlinePosition[     91763,       1914]
CellTagsIndexPosition[     91720,       1911]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 19 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"05779fbe-410b-4f87-b7ec-516ba15fa633"],

Cell["Chapter 2, Section 2.8, Figure 2.14", "Section",ExpressionUUID->"e63df341-f798-492c-be48-9ee16c60ee11"],

Cell[TextData[{
 "We start by a function ",
 StyleBox["r", "Input"],
 " using Eq.(2.20) to give us the radial distance for given values of \
semi-major axis, ",
 StyleBox["a", "Input"],
 ", eccentricity, ",
 StyleBox["e", "Input"],
 ", and true anomaly, ",
 StyleBox["f", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f4b31ab8-555a-4ae4-a87f-d193d66790bb"],

Cell["r[a_,e_,f_]:=a(1-e^2)/(1+e Cos[f]);", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[1]:=",ExpressionUUID->"dcc172f1-2935-470a-a867-5f83aa5ceb10"],

Cell[TextData[{
 "Now define a fixed viewpoint, ",
 StyleBox["vp", "Input"],
 ", from which to view the 3D plots."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a0007e51-09cc-412e-b873-7e1d980429ba"],

Cell["vp = {1.300, -2.400, 2.000};", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[2]:=",ExpressionUUID->"9de712f4-ffc4-4c90-a61a-23de1e8c4c9d"],

Cell["Set up the points defining an ellipse in the X-Y plane.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.852535506345207*^9, 3.852535547776589*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"34bfc68c-99b8-4d2c-b94b-cd8ab878feb8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xyz0", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"r", "[", 
         RowBox[{"1.0", ",", "0.5", ",", "t"}], "]"}], " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], ",", 
       RowBox[{
        RowBox[{"r", "[", 
         RowBox[{"1.0", ",", "0.5", ",", "t"}], "]"}], " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], ",", "0"}], "}"}], ",", "\n", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"2", "Pi"}], ",", 
       RowBox[{"Pi", "/", "60"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8524550323689423`*^9, 3.852455032372922*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"0e376915-8fd5-499c-8b61-f5a9c5e9b62d"],

Cell["Define the RGB colour to be used for the 3D arrowheads.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525355602484217`*^9, 3.85253558792832*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1bc6f51f-3786-4763-aba6-8599670a2d28"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ccolour", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.852533343123155*^9, 3.852533350115405*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"857e11d4-9e67-4184-abb4-7e1dd13a9671"],

Cell["\<\
Define a function to draw a circle, with arrow, at the end of the X axis.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535629487727*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c77888b8-1de3-4b8c-90ef-f6ae58a47bc9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"circleX", "[", 
   RowBox[{"rad_", ",", "offset_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ParametricPlot3D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"offset", ",", 
        RowBox[{"rad", "*", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
        RowBox[{"rad", "*", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Theta]", ",", "0", ",", 
        RowBox[{"2", "Pi"}]}], "}"}], ",", 
      RowBox[{"PlotStyle", "->", 
       RowBox[{"Thickness", "[", "0.005", "]"}]}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"ccolour", ",", 
       RowBox[{"Arrowheads", "[", "0.03", "]"}], ",", 
       RowBox[{"Arrow", "[", 
        RowBox[{"Tube", "[", 
         RowBox[{"BSplineCurve", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"offset", ",", 
              RowBox[{"rad", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"-", "Pi"}], "/", "20"}], "]"}]}], ",", 
              RowBox[{"rad", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"-", "Pi"}], "/", "20"}], "]"}]}]}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"offset", ",", 
              RowBox[{"rad", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"-", "Pi"}], "/", "10"}], "]"}]}], ",", 
              RowBox[{"rad", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"-", "Pi"}], "/", "10"}], "]"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"offset", ",", 
              RowBox[{"rad", "*", 
               RowBox[{"Cos", "[", "0", "]"}]}], ",", 
              RowBox[{"rad", "*", 
               RowBox[{"Sin", "[", "0", "]"}]}]}], "}"}]}], "}"}], "]"}], 
         "]"}], "]"}]}], "}"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.852530333257227*^9, 3.8525304086068172`*^9}, {
   3.852530558154735*^9, 3.852530648536417*^9}, {3.8525307533107567`*^9, 
   3.8525307774217033`*^9}, 3.8525308423951693`*^9, 3.8525308864100122`*^9, {
   3.8525321033795357`*^9, 3.852532317715383*^9}, {3.852532351892086*^9, 
   3.852532362185829*^9}, {3.852532396866641*^9, 3.85253241656883*^9}, {
   3.852532524575098*^9, 3.852532525021137*^9}, {3.852532618043804*^9, 
   3.852532664681788*^9}, {3.852532696585359*^9, 3.852532697240665*^9}, {
   3.852532746071652*^9, 3.852532751615067*^9}, {3.852533374804676*^9, 
   3.852533400778474*^9}, {3.852533640296274*^9, 3.8525336470232763`*^9}, {
   3.852533791060368*^9, 3.852533860715954*^9}, {3.8525340922576227`*^9, 
   3.85253409260006*^9}, {3.852572124974773*^9, 3.8525721329911537`*^9}, {
   3.85257217039001*^9, 3.852572172180476*^9}, {3.852572378233522*^9, 
   3.852572393641234*^9}, 3.85257242393714*^9, {3.85257246398421*^9, 
   3.852572464951795*^9}, 3.852572529823399*^9},
 CellLabel->"In[5]:=",ExpressionUUID->"3652ce30-f56d-4e52-852d-b4fe08c65066"],

Cell["\<\
Define a function to draw a circle, with arrow, at the end of the Z axis.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.85253564256765*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9e30f975-d9be-4ece-95d5-877d0e85514d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"circleZ", "[", 
   RowBox[{"rad_", ",", "offset_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ParametricPlot3D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"rad", "*", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
        RowBox[{"rad", "*", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", "offset"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Theta]", ",", "0", ",", 
        RowBox[{"2", "Pi"}]}], "}"}], ",", 
      RowBox[{"PlotStyle", "->", 
       RowBox[{"Thickness", "[", "0.005", "]"}]}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"ccolour", ",", 
       RowBox[{"Arrowheads", "[", "0.03", "]"}], ",", 
       RowBox[{"Arrow", "[", 
        RowBox[{"Tube", "[", 
         RowBox[{"BSplineCurve", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rad", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"3", 
                  RowBox[{"Pi", "/", "4"}]}], "-", 
                 RowBox[{"Pi", "/", "20"}]}], "]"}]}], ",", 
              RowBox[{"rad", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"3", 
                  RowBox[{"Pi", "/", "4"}]}], "-", 
                 RowBox[{"Pi", "/", "20"}]}], "]"}]}], ",", "offset"}], "}"}],
             ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rad", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{
                 RowBox[{"3", 
                  RowBox[{"Pi", "/", "4"}]}], "-", 
                 RowBox[{"Pi", "/", "10"}]}], "]"}]}], ",", 
              RowBox[{"rad", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{
                 RowBox[{"3", 
                  RowBox[{"Pi", "/", "4"}]}], "-", 
                 RowBox[{"Pi", "/", "10"}]}], "]"}]}], ",", "offset"}], "}"}],
             ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"rad", "*", 
               RowBox[{"Cos", "[", 
                RowBox[{"3", 
                 RowBox[{"Pi", "/", "4"}]}], "]"}]}], ",", 
              RowBox[{"rad", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{"3", 
                 RowBox[{"Pi", "/", "4"}]}], "]"}]}], ",", "offset"}], 
             "}"}]}], "}"}], "]"}], "]"}], "]"}]}], "}"}], "]"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.852530333257227*^9, 3.8525304086068172`*^9}, {
   3.852530558154735*^9, 3.852530648536417*^9}, {3.8525307533107567`*^9, 
   3.8525307774217033`*^9}, 3.8525308423951693`*^9, {3.8525308864100122`*^9, 
   3.85253092293753*^9}, 3.852532737103771*^9, {3.8525328278286257`*^9, 
   3.852532855603735*^9}, {3.8525329272113457`*^9, 3.852532947840917*^9}, {
   3.852533005801093*^9, 3.852533008885957*^9}, {3.8525330565753*^9, 
   3.852533059692666*^9}, {3.852533180122869*^9, 3.852533190833643*^9}, {
   3.85253322865856*^9, 3.85253325183976*^9}, {3.852533370780944*^9, 
   3.852533371554509*^9}, {3.852533404861548*^9, 3.852533407354621*^9}, {
   3.852533874651873*^9, 3.8525339583782463`*^9}, 3.852534001203566*^9, {
   3.8525340876666117`*^9, 3.852534088112321*^9}, 3.852572185442327*^9, {
   3.8525722869554663`*^9, 3.852572296891017*^9}, {3.8525724406005983`*^9, 
   3.852572472159524*^9}, 3.8525725348627243`*^9},
 CellLabel->"In[6]:=",ExpressionUUID->"1398d984-0426-4b5a-a072-c893e20cdcad"],

Cell["\<\
Draw the two circles for use in the plots to denote rotation axis.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535691910995*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e5a24ef9-2e36-42fa-b1ad-7178d38ca7cd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cX", "=", 
   RowBox[{"circleX", "[", 
    RowBox[{"0.2", ",", "1.8"}], "]"}]}], ";", " ", 
  RowBox[{"cZ", "=", 
   RowBox[{"circleZ", "[", 
    RowBox[{"0.2", ",", "1.8"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.852530930762123*^9, 3.852530969441333*^9}, {
   3.852531307355262*^9, 3.852531309138297*^9}, 3.852532334956168*^9, 
   3.852533421050256*^9, {3.852535651777452*^9, 3.852535652481008*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"252528e2-40aa-4756-b12f-b27bc2a3cac5"],

Cell["\<\
Define a function to draw a set of red axes of unit vectors for x-y-z.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535762668989*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b8a8eb27-75de-4e3c-8f55-30f58984bbe9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"axesred", "[", "vec_", "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"Arrowheads", "[", "0.04", "]"}], ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"Tube", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"orig", ",", "vec"}], "}"}], ",", "0.02"}], "]"}], "]"}]}], 
     "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.852529070144017*^9, 3.852529072480816*^9}, {
  3.852530247114521*^9, 3.852530256682539*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"f1e1377c-633c-4f70-854a-860223c37998"],

Cell["\<\
Define a function to draw a set of blue axes of unit vectors for X-Y-Z.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.8525357716208477`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"06c35ab9-b0b8-40b6-b090-c02afe2d208d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"axesblue", "[", "vec_", "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", 
      RowBox[{"Arrowheads", "[", "0.04", "]"}], ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{"Tube", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"orig", ",", "vec"}], "}"}], ",", "0.02"}], "]"}], "]"}]}], 
     "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.85245513621462*^9, 3.852455151342005*^9}, {
  3.852530260627121*^9, 3.852530262969915*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"51024ddd-924d-498c-ad34-6d51ff7c2881"],

Cell["\<\
Set up the basic axes, labels and a plane to denote the ecliptic.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535805628477*^9}, {
  3.852535881428327*^9, 3.85253589933282*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"67043386-4d59-4e57-a499-e40e376b532f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ax", "=", 
   RowBox[{"{", 
    RowBox[{"1.8", ",", "0", ",", "0"}], "}"}]}], ";", " ", 
  RowBox[{"ay", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1.8", ",", "0"}], "}"}]}], ";", " ", 
  RowBox[{"az", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1.8"}], "}"}]}], ";", " ", 
  RowBox[{"orig", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xlab", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"Text", "[", 
     RowBox[{"\"\<X\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"1.65", ",", "0", ",", 
        RowBox[{"-", "0.2"}]}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ylab", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"Text", "[", 
     RowBox[{"\"\<Y\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"0.1", ",", "1.7", ",", "0.1"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zlab", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"Text", "[", 
     RowBox[{"\"\<Z\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"0.2", ",", "0", ",", "1.65"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"aX", ",", "aY", ",", "aZ"}], "}"}], "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"axesblue", "[", "#", "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"ax", ",", "ay", ",", "az"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"OaX", ",", "OaY", ",", "OaZ"}], "}"}], "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"axesred", "[", "#", "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"ax", ",", "ay", ",", "az"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"originalaxes", "=", 
   RowBox[{"{", 
    RowBox[{"aX", ",", "aY", ",", "aZ"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ecliptic", "=", "\n", 
   RowBox[{"Graphics3D", "[", "\n", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"GrayLevel", "[", "1", "]"}], ",", 
      RowBox[{"Opacity", "[", "0.5", "]"}], ",", 
      RowBox[{"Polygon", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1.6", ",", "1.6", ",", 
           RowBox[{"-", "0.001"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.6"}], ",", "1.6", ",", 
           RowBox[{"-", "0.001"}]}], "}"}], ",", "\n", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.6"}], ",", 
           RowBox[{"-", "1.6"}], ",", 
           RowBox[{"-", "0.001"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1.6", ",", 
           RowBox[{"-", "1.6"}], ",", 
           RowBox[{"-", "0.001"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.852455072151498*^9, 3.852455072154038*^9}, {
   3.852455174334524*^9, 3.852455278076873*^9}, {3.852455643806073*^9, 
   3.852455740260494*^9}, {3.852455940820121*^9, 3.85245597107213*^9}, {
   3.852456236888843*^9, 3.8524562676779823`*^9}, {3.8524665494557056`*^9, 
   3.852466693659786*^9}, {3.8524667310279827`*^9, 3.85246676886753*^9}, {
   3.852466840470213*^9, 3.852466894506056*^9}, 3.852467043482765*^9, {
   3.8525302689863653`*^9, 3.8525303104249287`*^9}, 3.852531018505537*^9, {
   3.8525313901218224`*^9, 3.8525314089366903`*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"f877f1cb-57e9-409f-aef3-d7ceea1b068c"],

Cell[TextData[{
 "Define the ",
 StyleBox["OrbitPlots",
  FontWeight->"Bold"],
 " function.  This will plot the reference and transformed axes for given \
values of the inclination, ",
 StyleBox["i",
  FontWeight->"Bold"],
 ", argument of pericentre, ",
 StyleBox["\[Omega]",
  FontWeight->"Bold"],
 ", and longitude of ascending node, ",
 StyleBox["\[CapitalOmega]",
  FontWeight->"Bold"],
 ".  The value of ",
 StyleBox["rotc",
  FontWeight->"Bold"],
 " determines whether or not a rotation circle and directional arrow are \
plotted around either the X (",
 StyleBox["rotc",
  FontWeight->"Bold"],
 "=2) or Z (",
 StyleBox["rotc",
  FontWeight->"Bold"],
 "=1) axes.  The various 3x3 transformation matrices are defined in Sect.2.8 \
of the book."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535805628477*^9}, {
  3.852535881428327*^9, 3.852536118432987*^9}, {3.852536203928673*^9, 
  3.852536242888193*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ef8f25f0-a856-4688-a767-eed688aacf14"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OrbitPlots", "[", 
   RowBox[{"i_", ",", "\[Omega]_", ",", "\[CapitalOmega]_", ",", "rotc_"}], 
   "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"P1", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", "\[Omega]", "]"}], ",", 
          RowBox[{"-", 
           RowBox[{"Sin", "[", "\[Omega]", "]"}]}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sin", "[", "\[Omega]", "]"}], ",", 
          RowBox[{"Cos", "[", "\[Omega]", "]"}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"P2", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"Cos", "[", "i", "]"}], ",", 
          RowBox[{"-", 
           RowBox[{"Sin", "[", "i", "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"Sin", "[", "i", "]"}], ",", 
          RowBox[{"Cos", "[", "i", "]"}]}], "}"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"P3", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", "\[CapitalOmega]", "]"}], ",", 
          RowBox[{"-", 
           RowBox[{"Sin", "[", "\[CapitalOmega]", "]"}]}], ",", "0"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sin", "[", "\[CapitalOmega]", "]"}], ",", 
          RowBox[{"Cos", "[", "\[CapitalOmega]", "]"}], ",", "0"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"P", "=", 
      RowBox[{"P3", ".", "P2", ".", "P1"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"X", ",", "Y", ",", "Z"}], "}"}], "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"P", ".", "#"}], ")"}], "&"}], ",", 
        RowBox[{"{", 
         RowBox[{"ax", ",", "ay", ",", "az"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"OX", ",", "OY", ",", "OZ"}], "}"}], "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"axesred", "[", "#", "]"}], "&"}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "Y", ",", "Z"}], "}"}]}], "]"}]}], ";", 
     RowBox[{"finalaxes", "=", 
      RowBox[{"{", 
       RowBox[{"OX", ",", "OY", ",", "OZ"}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xyz", "=", 
      RowBox[{"N", "[", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"P", ".", "#"}], ")"}], "&"}], ",", "xyz0"}], "]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ell3D", "=", 
      RowBox[{"Graphics3D", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"GrayLevel", "[", "0.9", "]"}], ",", 
         RowBox[{"Polygon", "[", "xyz", "]"}]}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{
      "ell3D", ",", "finalaxes", ",", "originalaxes", ",", "ecliptic", ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"rotc", "==", "1"}], ",", "cZ", ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"rotc", "==", "2"}], ",", "cX", ",", 
           RowBox[{"Graphics3D", "[", 
            RowBox[{"Point", "[", "orig", "]"}], "]"}]}], "]"}]}], "]"}], ",",
        "xlab", ",", "ylab", ",", "zlab", ",", "\[IndentingNewLine]", 
       RowBox[{"Boxed", "->", "False"}], ",", 
       RowBox[{"SphericalRegion", "->", "True"}], ",", 
       RowBox[{"Lighting", "->", "False"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "->", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.6"}], ",", "1.82"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.6"}], ",", "1.82"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.6"}], ",", "1.82"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"ViewPoint", "->", "vp"}]}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8523663694230433`*^9, 3.8523664862422733`*^9}, {
   3.852366611635578*^9, 3.8523666473612747`*^9}, {3.852366682905582*^9, 
   3.852366755284726*^9}, {3.852367646994536*^9, 3.852367651522007*^9}, {
   3.852367738971428*^9, 3.85236775670152*^9}, {3.8523677897918873`*^9, 
   3.852367790855768*^9}, {3.852373058776144*^9, 3.8523730641314793`*^9}, 
   3.852373132482732*^9, {3.852373209829453*^9, 3.852373241075569*^9}, {
   3.852373296718609*^9, 3.8523734011141043`*^9}, {3.8523734750656757`*^9, 
   3.852373512462964*^9}, {3.852373558889861*^9, 3.852373571626051*^9}, {
   3.852373623916692*^9, 3.852373659417144*^9}, 3.8523737289492073`*^9, {
   3.8523741733943453`*^9, 3.852374187854589*^9}, {3.8523780182420473`*^9, 
   3.85237803666327*^9}, 3.852378355217454*^9, {3.852378427937359*^9, 
   3.852378456391492*^9}, {3.852378521972739*^9, 3.85237854111128*^9}, {
   3.852378626405312*^9, 3.852378724845235*^9}, {3.852380825929387*^9, 
   3.852380844131444*^9}, {3.8524493444945803`*^9, 3.85244941914929*^9}, {
   3.8524499495037317`*^9, 3.852450031958137*^9}, {3.852450726669446*^9, 
   3.85245073727488*^9}, 3.852454500790194*^9, {3.852454746401718*^9, 
   3.852454944547532*^9}, {3.85245558340059*^9, 3.852455588319963*^9}, 
   3.852456138679851*^9, 3.852456241646624*^9, {3.8524562768765697`*^9, 
   3.85245629824328*^9}, {3.852456368106683*^9, 3.8524563942500677`*^9}, {
   3.8524565611273737`*^9, 3.852456628517189*^9}, {3.8524582954311132`*^9, 
   3.852458296085181*^9}, {3.852460567306382*^9, 3.8524605750319347`*^9}, 
   3.852460789506646*^9, {3.852464882303657*^9, 3.852464929394867*^9}, {
   3.8524650082639017`*^9, 3.852465024818969*^9}, {3.852465108818759*^9, 
   3.852465189542272*^9}, {3.8524667860231447`*^9, 3.8524667961633883`*^9}, {
   3.852529206930707*^9, 3.852529209185336*^9}, {3.852531035168294*^9, 
   3.8525310373111362`*^9}, {3.852531112988882*^9, 3.852531117108981*^9}, 
   3.852532553327829*^9, {3.8525328079278393`*^9, 3.852532809997335*^9}, {
   3.85253415101926*^9, 3.852534241836462*^9}, {3.852534593115531*^9, 
   3.852534633273737*^9}, {3.852534725297579*^9, 3.852534734550969*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"833cd61d-07b2-413f-b484-11b9829ef206"],

Cell["\<\
Display the final configuration for specific values of the three rotation \
angles.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535805628477*^9}, {
  3.852535881428327*^9, 3.852536118432987*^9}, {3.852536203928673*^9, 
  3.852536242888193*^9}, {3.8814777480702047`*^9, 3.88147777434899*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7be7d1b2-aa16-4bd2-899e-0ffcfc4cbbd1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OrbitPlots", "[", 
  RowBox[{
   RowBox[{"60", "\[Degree]"}], ",", 
   RowBox[{"70", "\[Degree]"}], ",", 
   RowBox[{"40", "\[Degree]"}], ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.852373814300861*^9, 3.852373831041306*^9}, {
  3.852378405930765*^9, 3.8523784064840717`*^9}, {3.852444574374269*^9, 
  3.852444577013468*^9}, {3.852444706682804*^9, 3.852444710857604*^9}, {
  3.852534280606179*^9, 3.852534282908753*^9}, {3.852534350628705*^9, 
  3.8525343561637363`*^9}, {3.852534642161298*^9, 3.8525346432311363`*^9}, {
  3.852536133481573*^9, 3.8525361345214453`*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"7fd2dd4e-52bc-4610-b507-21bf1eab7a1d"],

Cell[BoxData[
 Graphics3DBox[{
   {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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     "]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {-0.07201576178665542, 1.0435850380609761`, 
      1.4648358264288728`}}, 0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {-1.4935850380609763`, -0.8514386251926501, 
      0.5331566389068428}}, 0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {1.0020067186075547`, -1.1941451067040891`, 0.9}}, 
     0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
   {GrayLevel[1], Opacity[0.5], 
    Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
     1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]}, 
   Point3DBox[{0, 0, 0}], Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
   Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
   Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
  Boxed->False,
  Lighting->False,
  PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
  SphericalRegion->True,
  ViewPoint->{1.3, -2.4, 2.}]], "Output",
 CellChangeTimes->{{3.852378399310581*^9, 3.852378407828208*^9}, 
   3.852378547541182*^9, 3.852380154045643*^9, 3.852380326681987*^9, 
   3.8523808503566732`*^9, 3.852444475401033*^9, {3.852444577906727*^9, 
   3.852444582735711*^9}, 3.8524447115812263`*^9, 3.852446084958755*^9, 
   3.852456433502329*^9, 3.852456603917859*^9, 3.8524566447758083`*^9, 
   3.8524605839977617`*^9, 3.8524609869455233`*^9, 3.852464935821768*^9, 
   3.8524650394836607`*^9, 3.852465141567812*^9, 3.8524651953961554`*^9, 
   3.852465290031794*^9, 3.852466811900235*^9, {3.852466874874168*^9, 
   3.852466900924855*^9}, 3.852467054204668*^9, 3.8525290811178217`*^9, 
   3.8525292146481647`*^9, 3.852530312581037*^9, 3.852531122739458*^9, 
   3.852531339882201*^9, 3.8525314203468933`*^9, 3.852532483658257*^9, {
   3.852532538058654*^9, 3.852532557269662*^9}, {3.852532649420203*^9, 
   3.852532706457687*^9}, 3.8525327733290577`*^9, 3.852532890259429*^9, {
   3.852532957035873*^9, 3.8525329780395403`*^9}, 3.852533031033733*^9, 
   3.8525330732532387`*^9, 3.852533204256501*^9, 3.85253326409923*^9, 
   3.85253343818744*^9, 3.852533975625881*^9, 3.8525340157966757`*^9, 
   3.8525340615950003`*^9, 3.852534107527691*^9, {3.852534265124349*^9, 
   3.852534284798882*^9}, {3.852534351685446*^9, 3.8525343570388403`*^9}, {
   3.852534638914278*^9, 3.8525346434858513`*^9}, 3.852534740384254*^9, 
   3.852536261458724*^9, 3.8525367491478777`*^9, 3.852572138832901*^9, 
   3.852572254910359*^9, 3.852572398723446*^9, {3.8525724446437683`*^9, 
   3.852572474587914*^9}, 3.85257260605926*^9, 3.85257265067542*^9, 
   3.881478251988456*^9, 3.890900702963769*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"025361b2-7879-483c-b8e5-5245c229eb96"]
}, Open  ]],

Cell["Display the initial configuration.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535805628477*^9}, {
  3.852535881428327*^9, 3.852536118432987*^9}, {3.852536203928673*^9, 
  3.852536242888193*^9}, {3.8814777480702047`*^9, 3.88147779716459*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1d14ebf4-e68b-47e0-b628-9d44f51af255"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{"OrbitPlots", "[", 
   RowBox[{
    RowBox[{"0", "\[Degree]"}], ",", 
    RowBox[{"0", "\[Degree]"}], ",", 
    RowBox[{"0", "\[Degree]"}], ",", "0"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8523810615551033`*^9, 3.8523810656207123`*^9}, {
  3.8524592490107183`*^9, 3.8524592500415373`*^9}, {3.8525347624941*^9, 
  3.852534762725068*^9}, {3.8525349550594883`*^9, 3.852534955666621*^9}, {
  3.8525361400892982`*^9, 3.8525361408086147`*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"4f1f1603-0ef9-43c0-878a-83a4f146e46b"],

Cell[BoxData[
 Graphics3DBox[{
   {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
     "]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
   {GrayLevel[1], Opacity[0.5], 
    Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
     1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]}, 
   Point3DBox[{0, 0, 0}], Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
   Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
   Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
  Boxed->False,
  Lighting->False,
  PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
  SphericalRegion->True,
  ViewPoint->{1.3, -2.4, 2.}]], "Output",
 CellChangeTimes->{
  3.852444549377204*^9, 3.8524445827446203`*^9, 3.852456733470018*^9, 
   3.85245925296642*^9, 3.852460588116181*^9, 3.852460986956438*^9, 
   3.852464943770381*^9, 3.852465044575453*^9, 3.8524652022577543`*^9, 
   3.8524652900672083`*^9, 3.852466911816861*^9, 3.8524670597192307`*^9, 
   3.8525290811407433`*^9, 3.8525292146577044`*^9, 3.852530312595257*^9, 
   3.8525314500708447`*^9, 3.852534763998212*^9, 3.852534956950941*^9, 
   3.852536261517921*^9, 3.852536749169718*^9, 3.852572138846715*^9, 
   3.8525722549616613`*^9, 3.852572398734063*^9, {3.852572444657372*^9, 
   3.852572474600338*^9}, 3.852572606120566*^9, 3.8525726508162937`*^9, 
   3.881478252107629*^9, 3.890900702975402*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"5ca61e2e-b8ab-4603-9d68-d9999c7adb8f"]
}, Open  ]],

Cell["Rotate through the angle \[Omega] = 70\[Degree] about the Z-axis.", \
"Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535805628477*^9}, {
  3.852535881428327*^9, 3.852536118432987*^9}, {3.852536203928673*^9, 
  3.852536242888193*^9}, {3.8814777480702047`*^9, 3.881477853758255*^9}, {
  3.88147788756236*^9, 3.8814778882668543`*^9}, {3.881477923532687*^9, 
  3.881477927882909*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b3a8c03a-d62c-4d47-b59e-0f6488484684"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p2", "=", 
  RowBox[{"OrbitPlots", "[", 
   RowBox[{
    RowBox[{"0", "\[Degree]"}], ",", 
    RowBox[{"70", "\[Degree]"}], ",", 
    RowBox[{"0", "\[Degree]"}], ",", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.852380420509632*^9, 3.852380420944628*^9}, {
   3.8523809246358633`*^9, 3.852380951097877*^9}, {3.8523809939685793`*^9, 
   3.852381002080772*^9}, 3.852381225505616*^9, {3.852444456386067*^9, 
   3.852444490521521*^9}, {3.8524567435512953`*^9, 3.852456765261394*^9}, {
   3.852459257641944*^9, 3.852459258577326*^9}, {3.8525347731740513`*^9, 
   3.852534773637135*^9}, {3.85253496096316*^9, 3.8525349613784847`*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"1c3a85d2-a240-4465-be62-ab4fd5416740"],

Cell[BoxData[
 Graphics3DBox[{
   {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk0leseB3DTIQ2yq2s+aQt1MnRSprieYxcNdEkZo7iIo3DuQeiWaWdT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     "]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {0.6156362579862037, 1.6914467174146353`, 0.}}, 
     0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 0.6156362579862037, 0.}}, 
     0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
   {GrayLevel[1], Opacity[0.5], 
    Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
     1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
       Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
        "]]},
      Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
   {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
    Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
     0.1618033988749895, 1.8}, {-0.09079809994790937, 0.1782013048376736, 
     1.8}, {-0.1414213562373095, 0.1414213562373095, 1.8}}]]}, 
   Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
   Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
   Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
  Boxed->False,
  Lighting->False,
  PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
  SphericalRegion->True,
  ViewPoint->{1.3, -2.4, 2.}]], "Output",
 CellChangeTimes->{
  3.852380421408445*^9, {3.852380933453915*^9, 3.852380951868314*^9}, {
   3.8523810030641212`*^9, 3.852381009466127*^9}, 3.852381226681816*^9, {
   3.8524444754568777`*^9, 3.852444490926265*^9}, {3.852444553169175*^9, 
   3.852444582795414*^9}, {3.8524567444158363`*^9, 3.852456766218759*^9}, 
   3.852459260356385*^9, 3.852460593584777*^9, 3.852460986969067*^9, 
   3.8524649473269587`*^9, 3.852465047447159*^9, 3.852465205656651*^9, 
   3.85246529007983*^9, 3.8524669165406237`*^9, 3.852467063503601*^9, 
   3.8525290811509666`*^9, 3.8525292147154284`*^9, 3.852530312608665*^9, 
   3.8525314545184803`*^9, 3.8525347743897963`*^9, 3.852534961668293*^9, 
   3.8525362615376883`*^9, 3.852536749184833*^9, 3.852572138859*^9, 
   3.852572255009947*^9, 3.852572398744689*^9, {3.852572444670288*^9, 
   3.852572474614695*^9}, 3.852572606134432*^9, 3.8525726508342667`*^9, 
   3.881478252130382*^9, 3.8909007029899073`*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"73bdd3f4-4b7d-4a91-8387-6ae9b809c2b9"]
}, Open  ]],

Cell[TextData[{
 "Rotate through the angle ",
 StyleBox["I",
  FontSlant->"Italic"],
 " = 60\[Degree] about the X-axis."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535805628477*^9}, {
  3.852535881428327*^9, 3.852536118432987*^9}, {3.852536203928673*^9, 
  3.852536242888193*^9}, {3.8814777480702047`*^9, 3.881477903672472*^9}, {
  3.881477936314797*^9, 3.88147794091721*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"06340237-b675-40c8-9d89-adaa184b83c2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p3", "=", 
  RowBox[{"OrbitPlots", "[", 
   RowBox[{
    RowBox[{"60", "\[Degree]"}], ",", 
    RowBox[{"70", "\[Degree]"}], ",", 
    RowBox[{"0", "\[Degree]"}], ",", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.852380420509632*^9, 3.852380420944628*^9}, {
   3.8523809246358633`*^9, 3.852380951097877*^9}, {3.8523809939685793`*^9, 
   3.852381002080772*^9}, 3.852381225505616*^9, {3.852444456386067*^9, 
   3.852444490521521*^9}, 3.852444559910759*^9, {3.852444611157506*^9, 
   3.852444619573037*^9}, {3.852444654381534*^9, 3.852444659371697*^9}, {
   3.852456782558415*^9, 3.8524567892688417`*^9}, {3.8524592640501127`*^9, 
   3.852459265008973*^9}, {3.852534781682221*^9, 3.852534782132825*^9}, {
   3.852534968971693*^9, 3.852534969674604*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"0ca578a4-e09b-48a1-8b42-79c6530ccb68"],

Cell[BoxData[
 Graphics3DBox[{
   {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAofxhWXFgnJWqEmytYqS+WfCS1acEuIyitxFSp7V8iEylJU0o1r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     "]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {0.6156362579862037, 0.8457233587073176, 
      1.4648358264288728`}}, 0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 0.30781812899310185`, 
      0.5331566389068428}}, 0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0., -1.5588457268119895`, 0.9}}, 
     0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
   {GrayLevel[1], Opacity[0.5], 
    Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
     1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
       Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
        "]]},
      Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
   {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
    Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
     0.19753766811902757`, -0.03128689300804618}, {1.8, 
     0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 0.}}]]}, 
   Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
   Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
   Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
  Boxed->False,
  Lighting->False,
  PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
  SphericalRegion->True,
  ViewPoint->{1.3, -2.4, 2.}]], "Output",
 CellChangeTimes->{{3.852444582807111*^9, 3.852444621405051*^9}, 
   3.852444660407256*^9, 3.852456790124343*^9, 3.852459267042406*^9, 
   3.852460598326964*^9, 3.852460986979949*^9, 3.852464950240081*^9, 
   3.852465051815103*^9, 3.85246520980832*^9, 3.852465290114893*^9, 
   3.8524669221210938`*^9, 3.8524670672617397`*^9, 3.8525290811616507`*^9, 
   3.8525292147260313`*^9, 3.852530312618573*^9, 3.852531460082572*^9, 
   3.8525347826877413`*^9, 3.852534970687194*^9, 3.852536261551614*^9, 
   3.852536749199881*^9, 3.852572138870838*^9, 3.852572255058742*^9, 
   3.852572398755088*^9, {3.852572444682293*^9, 3.8525724746270437`*^9}, 
   3.852572606147358*^9, 3.852572650852107*^9, 3.881478252223634*^9, 
   3.890900703003718*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"10f75ff9-a816-47d7-b644-89f9d47bbe1c"]
}, Open  ]],

Cell["Rotate through the angle \[CapitalOmega] = 40\[Degree] about the \
Z-axis.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535805628477*^9}, {
  3.852535881428327*^9, 3.852536118432987*^9}, {3.852536203928673*^9, 
  3.852536242888193*^9}, {3.8814777480702047`*^9, 3.881477903672472*^9}, {
  3.881477948281983*^9, 3.881477976797102*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ef313ec0-94c0-487f-92ff-0b13cd95f5ba"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p4", "=", 
  RowBox[{"OrbitPlots", "[", 
   RowBox[{
    RowBox[{"60", "\[Degree]"}], ",", 
    RowBox[{"70", "\[Degree]"}], ",", 
    RowBox[{"40", "\[Degree]"}], ",", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.852380420509632*^9, 3.852380420944628*^9}, {
   3.8523809246358633`*^9, 3.852380951097877*^9}, {3.8523809939685793`*^9, 
   3.852381002080772*^9}, 3.852381225505616*^9, {3.852444456386067*^9, 
   3.852444490521521*^9}, 3.852444559910759*^9, {3.852444611157506*^9, 
   3.852444619573037*^9}, {3.852444654381534*^9, 3.8524446713411913`*^9}, {
   3.852456812775723*^9, 3.8524568180126047`*^9}, {3.85245927190593*^9, 
   3.852459272865191*^9}, {3.8525347903337183`*^9, 3.852534792740693*^9}, {
   3.852534981811583*^9, 3.852534982097989*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"16994a69-855e-46a4-8c08-dcc1717174bd"],

Cell[BoxData[
 Graphics3DBox[{
   {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC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     "]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {-0.07201576178665542, 1.0435850380609761`, 
      1.4648358264288728`}}, 0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {-1.4935850380609763`, -0.8514386251926501, 
      0.5331566389068428}}, 0.02]]}, 
   {RGBColor[1, 0, 0], Arrowheads[0.04], 
    Arrow3DBox[
     TubeBox[{{0, 0, 0}, {1.0020067186075547`, -1.1941451067040891`, 0.9}}, 
     0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
   {RGBColor[0, 0, 1], Arrowheads[0.04], 
    Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
   {GrayLevel[1], Opacity[0.5], 
    Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
     1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
       Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
        "]]},
      Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
   {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
    Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
     0.1618033988749895, 1.8}, {-0.09079809994790937, 0.1782013048376736, 
     1.8}, {-0.1414213562373095, 0.1414213562373095, 1.8}}]]}, 
   Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
   Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
   Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
  Boxed->False,
  ImageSize->{360., 360.},
  ImageSizeRaw->Automatic,
  Lighting->False,
  PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
  SphericalRegion->True,
  ViewPoint->{1.3, -2.4, 2.},
  ViewVertical->{-0.017549883726549975`, 0.009971094716962628, 
   0.9997962686724381}]], "Output",
 CellChangeTimes->{
  3.85245681879396*^9, 3.852459274082631*^9, 3.852460603530384*^9, 
   3.8524609869914427`*^9, 3.852464954361578*^9, 3.8524650561718817`*^9, 
   3.852465216333837*^9, 3.85246529018519*^9, 3.852466928423379*^9, 
   3.8524670722973547`*^9, 3.8525290811767893`*^9, 3.852529214738916*^9, 
   3.852530312629949*^9, 3.8525314645675707`*^9, 3.85253479339153*^9, 
   3.852534982838595*^9, 3.85253626156723*^9, 3.8525367492165823`*^9, 
   3.8525721388841743`*^9, 3.85257225515536*^9, 3.8525723987686*^9, {
   3.852572444732267*^9, 3.852572474640718*^9}, 3.852572606160508*^9, 
   3.852572650871436*^9, 3.8814782523301563`*^9, 3.89090070301934*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"25612c1e-003a-4a6a-b00d-a1deb17f5316"]
}, Open  ]],

Cell["Display all four configurations. This is Fig.2.14.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8525356000561438`*^9, 3.852535805628477*^9}, {
   3.852535881428327*^9, 3.852536118432987*^9}, {3.852536203928673*^9, 
   3.852536242888193*^9}, {3.8814777480702047`*^9, 3.881477903672472*^9}, {
   3.881477948281983*^9, 3.881478020268004*^9}, 3.881478142307835*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c9e87bc3-179d-47d6-b30e-27472427e32b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"GraphicsGrid", "[", "\n", "  ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"p1", ",", "p2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"p3", ",", "p4"}], "}"}]}], "}"}], "]"}], ",", "\n", "  ", 
   RowBox[{"GraphicsSpacing", "->", "0.001"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.85245930229953*^9, 3.8524593023021097`*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"54d3b7b1-f963-4635-b992-136ce2d6a325"],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      Graphics3DBox[{
        {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJxl1g8w1GkYB/CN5sq0XUch2UUXnUHO0YXc3dspNFcdbQxD/6WmcndmuE5d
N9nMUcmUOc4lI47MXCEhbjbnRe36M2zyv41drFhshyz2Ns5103ne83hndnbm
szs7v33f532e7/qj3wjC9Dgcztk3L33O/OohHLRqYjevjtUqSIuwqGdImgaf
B4ZZr1jWpyAnh29IVNI74DcE6yzPlyvIbZeAv+3MS8Bj3EM1NfEKcuDVd0Yd
UhF4VofHVfF2BWlY2r/v46pK8FXvjNl5jcnJT63mfoPrHoPb2me4cRPl5PC4
v1lEVA24Z8dWXpuZnKR2/G5R1lgP3uCaZej7czcJKE92ublRCv6ypPQ1X6+b
SARGwmjaBP79qNpFtr+LrBA052873QyeN06D3st9TpJ1vMJYk1Zw/18+4n/e
LSPcqqhPTKvawOO8Rea9S2SkTlX2bu2pDnDjhAf3glY/I/Pv8y4seN2pb9hJ
4iMmzGJEMnB56wZHZ107idLMuasOdYHvuCPr2yhtI/YJcd4O+nLwZ8ZtqrVX
W8lNrZe6PVsBvtnl39VC0mqW2BRmsnPmLs+zSal+So61BXalfNUL7uqUvnWf
exPR8tcWeLr1gQdv2SQbdWgkvmHycl+OEnzillhtUFRHpE9EtT5i5nbHWnuH
5sSkp2c2/XZcP7jJYdXwuTXVpFTP+VDz9hfg+0Ildj7PH5KkM3GVG2aYWxXl
G9wwKiZeg2FrZAUD4CdsHq/NTskmeVNyP4uQwUX1+3apwCMvFbWvyc6h1pbh
DpHpzKu08Uv5mx7Q8rPBgV9+OARevMVxc/UXlbTi3syVnWXMXzhIrkZ4S2hz
FPfXaedh8KMiqxyPKw3UzWhZvzST+ayvfjM/4SndGx7Kt5hjrtx+JHVU00rr
ZkpCDXePgGfQigmlsJOGT7ysuP8j83y1KvOpUxf9LMpPN/DbCPq/PfTO7iDV
uVLmZk/2+1ya6qX20t7TFv/7flD/WEukTklnbJPSIy4w14hqi+oNBqjua5OQ
5a7MzyeHKC3fV9EGhVFWTCN7fm1mkjh+2zD97x3c52Sx+PoRNc30LHwynsj2
bay0Yg8R/kmjhVaPGovZ/psYrlwVv2eMVqkvJ/9QyM4xI8+cp/MfpxcynD9o
usjO/czBJSI3/1fU4x7nAM+O1YmFU7Rg784JOsM73h+Sy+owOit6xNFRQzUB
XqY7tKzO01S7BHf1Jqltk2Q6eD27F8p8p9mc6kl6vV1+gruT3bv7FZIh09NT
NFVza5f1sk7wpm8lgW5/TdFxkwirg5dawHPn0pWJp6bpp9PG1xLvNjIff+i5
8o9pevl4/sX6yUfgPANuvePoGx9uUdcblqDz1VIOWuj78Dn6feYLnwccPT84
+r/gaH/A0X6Co/0HR+cFjs4XHNUDOKofcFRv4Kg+wVE9g6P6B0f3BRzdL3B0
H9F5wv0FR/ed7cPC/sDOZWE/AUf9Bxz1K3DU38BRPwRH/RMc9dtF9ft2MUf9
HBz1f3A0L1g9LJwv4GgegaP5BY7mHTiaj+BonoKj+QuO5jU4mu/gKA+Ao/wA
jvIGOMon4CjPgKP8A47yEjjKV+Aoj4Gj/AaO8h44yofgKE+Co/wJjvIqOMq3
4CgP4/u7KH/8A+iE/+A=
          "]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0., 0.}}, 0.02]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 1.8, 0.}}, 0.02]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
        {GrayLevel[1], Opacity[0.5], 
         Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
          1.6, -0.001}, {-1.6, -1.6, -0.001}, {1.6, -1.6, -0.001}}]}, 
        Point3DBox[{0, 0, 0}], Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
        Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
        Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
       Boxed->False,
       Lighting->False,
       PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
       SphericalRegion->True,
       ViewPoint->{1.3, -2.4, 2.}], {192., -192.}, ImageScaled[{0.5, 0.5}], {360, 360},
      
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}},
      ContentSelectable->True], InsetBox[
      Graphics3DBox[{
        {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx11nk0leseB3DTIQ2yq2s+aQt1MnRSprieYxcNdEkZo7iIo3DuQeiWaWdT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          "]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[
          TubeBox[{{0, 0, 0}, {0.6156362579862037, 1.6914467174146353`, 0.}}, 
          0.02]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[
          TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 0.6156362579862037, 0.}},
           0.02]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0., 0., 1.8}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
        {GrayLevel[1], Opacity[0.5], 
         Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
          1.6, -0.001}, {-1.6, -1.6, -0.001}, {
          1.6, -1.6, -0.001}}]}, {{{}, {}, 
          TagBox[
           {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
            Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
             "]]},
           Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
        {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
         Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
          0.1618033988749895, 1.8}, {-0.09079809994790937, 0.1782013048376736,
           1.8}, {-0.1414213562373095, 0.1414213562373095, 1.8}}]]}, 
        Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
        Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
        Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
       Boxed->False,
       Lighting->False,
       PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
       SphericalRegion->True,
       ViewPoint->{1.3, -2.4, 2.}], {576., -192.}, ImageScaled[{0.5, 0.5}], {360, 360},
      
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}},
      ContentSelectable->True]}, {InsetBox[
      Graphics3DBox[{
        {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FAofxhWXFgnJWqEmytYqS+WfCS1acEuIyitxFSp7V8iEylJU0o1r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          "]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[
          TubeBox[{{0, 0, 0}, {0.6156362579862037, 0.8457233587073176, 
           1.4648358264288728`}}, 0.02]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[
          TubeBox[{{0, 0, 0}, {-1.6914467174146353`, 0.30781812899310185`, 
           0.5331566389068428}}, 0.02]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0., -1.5588457268119895`, 0.9}}, 
          0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
        {GrayLevel[1], Opacity[0.5], 
         Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
          1.6, -0.001}, {-1.6, -1.6, -0.001}, {
          1.6, -1.6, -0.001}}]}, {{{}, {}, 
          TagBox[
           {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
            Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3va1jnf1BnBE7woHcVN3edx8duCMj6VW
Qs9CHBT7xk+NB+SDGe+4eT3uz3042J3eMku5UoR8vqW5M+kTHLTr1oX9xJYi
p1uKPDa3YiBpXJhEs6lBzpRE9OXqzcDEEZ8udWlAnhnly+w9YAJP8uh2VE0z
8iabQ1XegjaQkLL0ZWKaFjn7QCKYzG8FD9de3ZdYrUf+QGjs8SPrALaTW+wx
bkD+ZNj6ewOvBWzbEJP6wyMj8p0DjAnZcCPghnUsm95lRv40+Lz9q9l1YNRq
9G8zH0MOFtd39AxUAc5T1+fe/xJeWWIstBdfAIrn29d3huDI9Vs1Gw93C8Cu
TDKtPJ3wafmEakSTBfrvpp9eKHjPpRHKYk0aXJ1x9lpmGeGuQ0uZ/6hKYBDN
KXzZccLp6vCh6Q0SaJ5Q1WgiCQ/5CGoNd2RQckEqLCcTPmcqYf5gZi20crrs
VVNKzD86QY9ekq2E5INR7dlzCa/ovUpbVaOC4bSsLUUNJuQ3Tq1lxMzRwDT/
BJeUecQ+zaW3C6g+eujy2ktlGWtFHjbyrTF7nwHOGZPIdPU65Drux/vvpxuh
MNfGwdpyFXnnbldIZ5ihj/0tedFUE/KjdGf+yggMzlvYszlhsQJ5NqV/bpAZ
g5yBnrYv1XLkA6Jk2exPcai0FcSwaUQ+RcnO2wu+w+F4SLRrXw6RZx+eGwnj
49BNu0nqc5bIP5P/o6VMhENOz89a/wZf5DTw2eEnhTjE+iLo/OQ8OOM2q2NP
VOzFIZf3uDpfI0J+8EXzXr07DvsdskpHSqTIublpnS9NGJRcHKqr18mRr6bs
CB2KxaB7ag41oPsScidF1FiqnRmeq4hc5M28jNxa2mfbFW+E7jsXbOV6qpHb
qWVMvywDjDvkljEk1CH3zhO8sHPXQxgQzIqmGpB7RahuUsI0cB31ntURKyNy
R9sSasUzFWSv8VM4VpiQO5Mv3ZtuVcIRlnTHOTKG3AJu/MHLq4OBD1K3MXII
j00ZDvRNrIahj6Ii1Y8J9//6QMTE5QvQPtmX0hiMIyd9034xqO8MFA56SWEG
4cv7FUW343jwSvsmjzoh4d1sqPr15hHQe735l7llhKe8eBbs6V8CdGtkyvJM
wnmMvO3xtefBUSbQ17EIV4s7xP9ZV4G7+8v915MIb5zMN/SLa4HDB0m/FQmI
+YfaXzlhGxuBe8xghumEGblsmgVYe1rAscy4l71PiX0GRdqzXo9C8Ber82Ej
uQ358SXZjzibWwGH0t0V8ECPnCG2bIk92QbssEH5brEWOcXHbfRQqAlI2Nia
zzdeQa5oWuG4QGoG/BKakCtvQH4nBE851YIBbI8eWB2rQU6dLNSu+BAHt5qH
v1DEVCLv+oofzWTjYPzZmaA3y8XEfe8fPkkqwMFIxiRzVSAf+cx/sWn6/djb
/6L9HzmT4CA=
             "]]},
           Annotation[#, "Charting`Private`Tag$1892#1"]& ]}, {}}, 
        {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
         Arrow3DBox[TubeBSplineCurveBox[{{1.8, 
          0.19753766811902757`, -0.03128689300804618}, {1.8, 
          0.1902113032590307, -0.06180339887498949}, {1.8, 0.2, 0.}}]]}, 
        Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
        Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
        Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
       Boxed->False,
       Lighting->False,
       PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
       SphericalRegion->True,
       ViewPoint->{1.3, -2.4, 2.}], {192., -576.}, ImageScaled[{0.5, 0.5}], {360, 360},
      
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}},
      ContentSelectable->True], InsetBox[
      Graphics3DBox[{
        {GrayLevel[0.9], Polygon3DBox[CompressedData["
1:eJx1lmk0FIobxokoWxEqKtREJNVNtitvt6IiQloIt4VskaVsCWVpodJCsqVC
Ubayi9fekGUYM2bG2MbMkOxbWdLfh/v1/+H59J7znPOe8zu/8yhcumZuv4KH
h8dvOXzL2SDVuVEw4Dm2vy7L9X3YBjIvba+9FmLAFh1+1zGrVMzmzrjplrdC
kBrvbHQIA87WHW8K187BRB+OuwmXBPXz6XvOjDNge663tkp1PobK3GSnriQB
ReKjBMW0E57OD9SdNSzFpimlYketZqh3JScvpnRChO6luUCHChwXdpBpPNUI
3teFCzOHO+G+5dWZ4B3VOB2mLHzEpgEW35XWoRITPkoWF20ZrEWRqpT25xZE
2GwU95DnDBOqTpuf1Esj4q+7wpf8tOsgWYlUs8+HCV4pxNKyS9/wi0pT2Vvh
GnCkOBAlIpjQnzOe7rG5Gc30jGLLGiqh/reS5oknTHi633iFhAsJrRK7C1uH
yyGCRogIuc+EY3Hj6sfrWnFSmpAWvKkE2FURH0y9mHBUsEhXQ56Mwxvu1eds
y4foHjdfMGGCbw534b1vO9oxg5lBvDngQEg3a9nIhMFrZRccWyg4ePvFEr9z
KvjePxfnSekE+iPtI3sJHVjkvXeTzMxzCDgyqPMouBOczFR25nvTkOfmIcFn
GZbILtcl+Ml0wqJzDje2jo6m5Vv9NvXEYmy6UcfNNwxwN/1L3GtdJ+aJxbms
cnuPkeaGMy3rGWD4kmHXYM1EDaPHj0zsP6GnZEbXKz865NbTB9e96UJWU3Vq
eHUR8vPZXhD4SgONwOHJHFY36hll2PibIwbKXYkU+9MB93gf35oV60Uh4TtD
bqur0X2rXcpn+Q7Id9BJvpXei6ItQmGv79ShtLiUfp8KFS7AFjn/g33I5/JY
bJVUA7Z/mvvmtYkCPxfC/ZzIfahKMOAtqWjCA4H6a7SnyfDyrvlS0UUW5tkG
W1OrSFjDb31zIqcN7AniR2uGWEjyNPpJyW3D/dJFmWZmrWD6ipJCdu1Ho507
H+3IbEfxa6Lmq9+3wAVtkzCZoX70q86iBeRRkTdzMtTmWiOscXKh59uy8bTW
miWbrzT8fMKVzpohAt8LxQcZDWxUEbe33sVhYF2ApUSvVi2o/vNbmK3KwaEN
3HhZ0S7cJrKe/mF/JXxk3FTcF8pB0tVWUQW9HhS5kLvRh1wMp9JqhYxbOEhs
Mc32L+1Fw+htvs6pOfBp2orRIMLF/u2LZ/g6+5BYq2apfD0etL6erlP+m4vX
7cOlixZZGExoKIo4Fonnv32c/XaOi9Tpf//2lWOjPCtmVeaWTPwWdNZ9/jIX
NZvjZ8b+4aBkoWTRlEYJVmyr1hy04qJKgGzJs0tcNJAf3V0H1ah0eHaiYLk/
9dZt2YSgASyx4Xf3+FyP363rjt3i52JUbKvriheDuHMpQkBOh4TJ+kIWJz9z
0NlhPC4w7TsmJmfankQySvQyDx434CCPSdOr8A9DGHv3iErVlQ5ULq22TShl
45pNlVqmb39gRQDfYeldnfjbZTApSZyN/t1pJygPhnFLkZ7KvGgPbiucc2Ia
9GNXY1tqp+0IqimqOorc6UOex1K3VK1YSBvW8+fZNIq+IsrzYaH96PR6j16t
YR/WnuXdTiwfxdGqvN0fHnDwsR0923xDL3qeloJPh8ewOV1SVT1qABX6HCvX
h3fhg6n1C2bvxtDnUYj+uajv6Fj1hhH5goF7LKWPOXPHMKz1wJuusB94INZ1
WMSxA+XVt5BElsbQoIfwbI/LCA7sY6dLLJLReGWGR8mPMQwWCSy/ozOGPWvv
dz61JOHWpZv2IZljqLpwt/qX9ziWEFv4B9bUo/1Xj1HCoTH0SHPYTYcJbLj7
y71PrhIzeX2ObU0fxaHoJH+FmQlMSrsTWTqSiwxdwyQqawRtDaL0jZ9P4vsS
5XN0kxu4ur5lW+D4MOYmdrxWlZ3ClFfENKGSLCj3TBDa3/4D2yfD183dnUL1
a7zW7nMI531n2n5EDeHD3o0Xr9CnUPQ2a0BQmQjm6rV2ZirfccuuL5OZYtOY
nPxWNkmMBEoUgcN5KQN4VUt+6pnSNGYqPLhrxSKDcVDLOHOZC2UvhVF7wjQa
meSeDAjvgA2rfRTZJ9nI0prTmlo5jT/uV1WJTzGgZeu6bMEIFlLDL04ENU3h
gg9z9qVCN8jPu2YHL/OvzHe25nPAFGb6qCRFhPeCk0uMV2ljF9rJrxoMk5rC
1mytAkF6H3zt7OOtlWegv9SfaqW4SeQrVt2hJ9gPtcVP3jJvUpGZUJoxJjKJ
ZDmB+I61bCjpNE4gc9rQvp/ZesR9Yvne/FJqlg20gETCWEMzxl687Pqwbhz3
lp5q+VLIAUne4SwJXiIG7TIJkZMYR5+5FfO/z3DBu9qq7ZZPJabuGrntlDGK
xscvztpSuHAMaY3aLgUY6O+TV7VtBB/weUykqA9A8rqDpjz8qag4lfBY9vkP
PPM9K7TCewCCrQ31Vyc5QuxS4y7u0nf0iDLe9yVxAHioOzkp9WlgLl5N+sth
EEcOytzO/DAAa5+0NN04nw9sRa5zTgsXJSgX0t+/GYCcttFDtPflsEr8cn+2
Dgdd+wI6CkIHoOaUxLVL76pBw+yXhXJGP4oXO2c0nxoA3bioed33X0EgMeJV
lRwLLTyyypvFByCmXURW1fIbeO89WEFN6MWsd+LTfhVcKHpokt70pRlK/K7/
mT/SjU4Puwg3LnLh35QkacEfJNAroB5UvNyJRAHHVQazHNBZoFgJWrRBTDMn
PiiahocSPXlPBXOgiPknRDCeDFmTN478ZlLwRjwm9/NwQH64oSezsh3O/N1/
/JgOGd/O3/6o4MeGoN82M6/qKRD9dJUrMZOE//kZ/vMz/Odn7I6MJlZY9INU
T0MDLaQDXDb/ObqU/RWbJgzWjxazQD6Uf0pbmwaLSk0LezZX44G47mE7GRaU
tLXzSlNpUMhdu3P8ahm+MJzxafPuA539cc9I5+nw2FPB1GQ2D1d8tnAitfTC
7J5itZJvdPjYvsO/ID0dd2vU53K390LUpuayNUoMkE/IEfgj8xx7J4fMZaa6
QTbXzmXejQF7CPmjYjkhkEUg61jFdAGP1xzxcQoDztks1PAefQuabZEh+hpM
UN1GU2sjMmB072e1/pAcyPtZsOYWmQE80SX6uUwGfFEM1bbYWAhqE6tyI93o
ULXIyhTqY4CAdHj0b/sySIg1dBgRpEHJDKU4g8oAqZx3DjwFlXD68/qrgslU
KE3rVjcuZ8DebH3N4pgauOEWIqauSQG1+xq7k2IZ4FGZNqNyZpmLf5cuYhMZ
CBvFvulcYQD7dJqm8Uw96G1aWfP9chscWt0h8Gn5X88sUXmRG42Q/2ar7vc5
ElQ4b74T1kWH8iEFq6PUZpCPueNFkWsBO/tFHZV7dHBLOZ82GEmCvTdPXFE8
0QgSlu2HVu+gQ/926wOaya3w8kWMGa9fPbgfvOQUXEYDYwVqiHNqG2wU1ZWP
SasD6quiLtYxGhACpVWpCWRofPrTVIhSDVFruDV+DR1wKL/gcl14OzBXKPn7
81fCuVjTutBDHWBzYDE/6DIFhFXfnvvp9AWspRYe6uRS4Srf2Sm9fVQQ/qno
rt1UAL23RPXrpalw0KBXVnuWCsHJ9wqb/8qFkQpJ3rNeFHD9I2QU/7EDBEpS
vML2vwP1mlCVFV/bYcx6/s2DMzSYdtd5cFUyFoSbNnT2ibdD4tOdGoRpGrjP
Dya4eluD2ZMydQELMiyomo4GhNHh/+3n/wGwzxVc
          "]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[
          TubeBox[{{0, 0, 0}, {-0.07201576178665542, 1.0435850380609761`, 
           1.4648358264288728`}}, 0.02]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[
          TubeBox[{{0, 0, 0}, {-1.4935850380609763`, -0.8514386251926501, 
           0.5331566389068428}}, 0.02]]}, 
        {RGBColor[1, 0, 0], Arrowheads[0.04], 
         Arrow3DBox[
          TubeBox[{{0, 0, 0}, {1.0020067186075547`, -1.1941451067040891`, 
           0.9}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {1.8, 0, 0}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 1.8, 0}}, 0.02]]}, 
        {RGBColor[0, 0, 1], Arrowheads[0.04], 
         Arrow3DBox[TubeBox[{{0, 0, 0}, {0, 0, 1.8}}, 0.02]]}, 
        {GrayLevel[1], Opacity[0.5], 
         Polygon3DBox[{{1.6, 1.6, -0.001}, {-1.6, 
          1.6, -0.001}, {-1.6, -1.6, -0.001}, {
          1.6, -1.6, -0.001}}]}, {{{}, {}, 
          TagBox[
           {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.005], 
            Line3DBox[CompressedData["
1:eJxN1X1U0mcUB3AkDG2a+JKj5sicNbPWMbOVK318q3CaLLXsRI3matXC1yyb
ozS1TQ2PaaDDKHKIDtMFvoQZ8IAI/H7Oypampp2Wskpr1qmtTFNXf/j8uufc
fz5/3XPv95y7KD4pei+ZRCJteNuz3jZH9K5wEDd1l8fNZwde63hXb8BYaiX0
LMRBsW/81HhAPpjxjpvX4/7ch4Pd6S2zlCtFyOdbmjuTPsFBu25d2E9sKXK6
pchjcysGksaFSTSbGuRMSURfrt4MTBzx6VKXBuSZUb7M3gMm8CSPbkfVNCNv
sjlU5S1oAwkpS18mpmmRsw8kgsn8VvBw7dV9idV65A+Exh4/sg5gO7nFHuMG
5E+Grb838FrAtg0xqT88MiLfOcCYkA03Am5Yx7LpXWbkT4PP27+aXQdGrUb/
NvMx5GBxfUfPQBXgPHV97v0v4ZUlxkJ78QWgeL59fWcIjly/VbPxcLcA7Mok
08rTCZ+WT6hGNFmg/2766YWC91waoSzWpMHVGWevZZYR7jq0lPmPqgQG0ZzC
lx0nnK4OH5reIIHmCVWNJpLwkI+g1nBHBiUXpMJyMuFzphLmD2bWQiuny141
pcT8oxP06CXZSkg+GNWePZfwit6rtFU1KhhOy9pS1GBCfuPUWkbMHA1M809w
SZlH7NNceruA6qOHLq+9VJaxVuRhI98as/cZ4JwxiUxXr0Ou4368/366EQpz
bRysLVeRd+52hXSGGfrY35IXTTUhP0p35q+MwOC8hT2bExYrkGdT+ucGmTHI
Gehp+1ItRz4gSpbN/hSHSltBDJtG5FOU7Ly94DscjodEu/blEHn24bmRMD4O
3bSbpD5nifwz+T9aykQ45PT8rPVv8EVOA58dflKIQ6wvgs5PzoMzbrM69kTF
XhxyeY+r8zUi5AdfNO/Vu+Ow3yGrdKREipybm9b50oRBycWhunqdHPlqyo7Q
oVgMuqfmUAO6LyF3UkSNpdqZ4bmKyEXezMvIraV9tl3xRui+c8FWrqcauZ1a
xvTLMsC4Q24ZQ0Idcu88wQs7dz2EAcGsaKoBuVeE6iYlTAPXUe9ZHbEyIne0
LaFWPFNB9ho/hWOFCbkz+dK96VYlHGFJd5wjY8gt4MYfvLw6GPggdRsjh/DY
lOFA38RqGPooKlL9mHD/rw9ETFy+AO2TfSmNwThy0jftF4P6zkDhoJcUZhC+
vF9RdDuOB6+0b/KoExLezYaqX28eAb3Xm3+ZW0Z4yotnwZ7+JUC3RqYszySc
x8jbHl97HhxlAn0di3C1uEP8n3UVuLu/3H89ifDGyXxDv7gWOHyQ9FuRgJh/
qP2VE7axEbjHDGaYTpiRy6ZZgLWnBRzLjHvZ+5TYZ1CkPev1KAR/sTofNpLb
kB9fkv2Is7kVcCjdXQEP9MgZYsuW2JNtwA4blO8Wa5FTfNxGD4WagISNrfl8
4xXkiqYVjgukZsAvoQm58gbkd0LwlFMtGMD26IHVsRrk1MlC7YoPcXCrefgL
RUwl8q6v+NFMNg7Gn50JerNcTNz3/uGTpAIcjGRMMlcF8pHP/Bebpt+Pvf0v
2hn/Hz8z4CA=
             "]]},
           Annotation[#, "Charting`Private`Tag$1976#1"]& ]}, {}}, 
        {RGBColor[0.368417, 0.506779, 0.709798], Arrowheads[0.03], 
         Arrow3DBox[TubeBSplineCurveBox[{{-0.11755705045849463`, 
          0.1618033988749895, 1.8}, {-0.09079809994790937, 0.1782013048376736,
           1.8}, {-0.1414213562373095, 0.1414213562373095, 1.8}}]]}, 
        Text3DBox["\<\"X\"\>", {1.65, 0, -0.2}], 
        Text3DBox["\<\"Y\"\>", {0.1, 1.7, 0.1}], 
        Text3DBox["\<\"Z\"\>", {0.2, 0, 1.65}]},
       Boxed->False,
       Lighting->False,
       PlotRange->{{-1.6, 1.82}, {-1.6, 1.82}, {-1.6, 1.82}},
       SphericalRegion->True,
       ViewPoint->{1.3, -2.4, 2.}], {576., -576.}, ImageScaled[{0.5, 0.5}], {360, 360},
      
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}},
      ContentSelectable->True]}}, {}},
  GraphicsSpacing -> 0.001,
  ImageSize->Automatic,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.852459305110222*^9, 3.85246061134135*^9, 3.852460987328471*^9, 
   3.852464960290338*^9, 3.8524650597093973`*^9, 3.852465222203807*^9, 
   3.852465290761191*^9, 3.852466952800222*^9, 3.852467078078985*^9, 
   3.8525290815867233`*^9, 3.852529215083949*^9, 3.8525303131319103`*^9, 
   3.85253149381744*^9, 3.852534801702043*^9, 3.8525349897261753`*^9, 
   3.852536261903882*^9, 3.852536749615987*^9, 3.8525721392109547`*^9, 
   3.85257225571778*^9, 3.852572399085998*^9, {3.852572445058536*^9, 
   3.8525724749605637`*^9}, 3.8525726064869347`*^9, 3.852572651388859*^9, 
   3.881478253142106*^9, 3.890900703476543*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"8bb5b755-fddf-4a07-939c-b56fada612d6"]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{924, 636},
WindowMargins->{{126, Automatic}, {Automatic, 19}},
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"8c5410ea-ca8d-4fcd-8cd5-bb167c5ea7f9"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 387, 8, 53, "Text",ExpressionUUID->"05779fbe-410b-4f87-b7ec-516ba15fa633"],
Cell[948, 30, 109, 0, 67, "Section",ExpressionUUID->"e63df341-f798-492c-be48-9ee16c60ee11"],
Cell[1060, 32, 408, 14, 72, "Text",ExpressionUUID->"f4b31ab8-555a-4ae4-a87f-d193d66790bb"],
Cell[1471, 48, 188, 3, 30, "Input",ExpressionUUID->"dcc172f1-2935-470a-a867-5f83aa5ceb10"],
Cell[1662, 53, 236, 7, 53, "Text",ExpressionUUID->"a0007e51-09cc-412e-b873-7e1d980429ba"],
Cell[1901, 62, 181, 3, 30, "Input",ExpressionUUID->"9de712f4-ffc4-4c90-a61a-23de1e8c4c9d"],
Cell[2085, 67, 247, 4, 53, "Text",ExpressionUUID->"34bfc68c-99b8-4d2c-b94b-cd8ab878feb8"],
Cell[2335, 73, 754, 20, 52, "Input",ExpressionUUID->"0e376915-8fd5-499c-8b61-f5a9c5e9b62d"],
Cell[3092, 95, 248, 4, 53, "Text",ExpressionUUID->"1bc6f51f-3786-4763-aba6-8599670a2d28"],
Cell[3343, 101, 315, 7, 33, "Input",ExpressionUUID->"857e11d4-9e67-4184-abb4-7e1dd13a9671"],
Cell[3661, 110, 275, 6, 53, "Text",ExpressionUUID->"c77888b8-1de3-4b8c-90ef-f6ae58a47bc9"],
Cell[3939, 118, 3179, 71, 115, "Input",ExpressionUUID->"3652ce30-f56d-4e52-852d-b4fe08c65066"],
Cell[7121, 191, 274, 6, 53, "Text",ExpressionUUID->"9e30f975-d9be-4ece-95d5-877d0e85514d"],
Cell[7398, 199, 3609, 84, 136, "Input",ExpressionUUID->"1398d984-0426-4b5a-a072-c893e20cdcad"],
Cell[11010, 285, 268, 6, 53, "Text",ExpressionUUID->"e5a24ef9-2e36-42fa-b1ad-7178d38ca7cd"],
Cell[11281, 293, 523, 11, 30, "Input",ExpressionUUID->"252528e2-40aa-4756-b12f-b27bc2a3cac5"],
Cell[11807, 306, 272, 6, 53, "Text",ExpressionUUID->"b8a8eb27-75de-4e3c-8f55-30f58984bbe9"],
Cell[12082, 314, 643, 16, 52, "Input",ExpressionUUID->"f1e1377c-633c-4f70-854a-860223c37998"],
Cell[12728, 332, 275, 6, 53, "Text",ExpressionUUID->"06c35ab9-b0b8-40b6-b090-c02afe2d208d"],
Cell[13006, 340, 644, 16, 52, "Input",ExpressionUUID->"51024ddd-924d-498c-ad34-6d51ff7c2881"],
Cell[13653, 358, 315, 7, 53, "Text",ExpressionUUID->"67043386-4d59-4e57-a499-e40e376b532f"],
Cell[13971, 367, 3527, 101, 241, "Input",ExpressionUUID->"f877f1cb-57e9-409f-aef3-d7ceea1b068c"],
Cell[17501, 470, 1037, 32, 122, "Text",ExpressionUUID->"ef8f25f0-a856-4688-a767-eed688aacf14"],
Cell[18541, 504, 6760, 155, 346, "Input",ExpressionUUID->"833cd61d-07b2-413f-b484-11b9829ef206"],
Cell[25304, 661, 430, 9, 53, "Text",ExpressionUUID->"7be7d1b2-aa16-4bd2-899e-0ffcfc4cbbd1"],
Cell[CellGroupData[{
Cell[25759, 674, 680, 12, 30, "Input",ExpressionUUID->"7fd2dd4e-52bc-4610-b507-21bf1eab7a1d"],
Cell[26442, 688, 6879, 119, 377, "Output",ExpressionUUID->"025361b2-7879-483c-b8e5-5245c229eb96"]
}, Open  ]],
Cell[33336, 810, 373, 6, 53, "Text",ExpressionUUID->"1d14ebf4-e68b-47e0-b628-9d44f51af255"],
Cell[CellGroupData[{
Cell[33734, 820, 565, 11, 30, "Input",ExpressionUUID->"4f1f1603-0ef9-43c0-878a-83a4f146e46b"],
Cell[34302, 833, 3630, 66, 377, "Output",ExpressionUUID->"5ca61e2e-b8ab-4603-9d68-d9999c7adb8f"]
}, Open  ]],
Cell[37947, 902, 506, 9, 53, "Text",ExpressionUUID->"b3a8c03a-d62c-4d47-b59e-0f6488484684"],
Cell[CellGroupData[{
Cell[38478, 915, 734, 13, 30, "Input",ExpressionUUID->"1c3a85d2-a240-4465-be62-ab4fd5416740"],
Cell[39215, 930, 6990, 125, 377, "Output",ExpressionUUID->"73bdd3f4-4b7d-4a91-8387-6ae9b809c2b9"]
}, Open  ]],
Cell[46220, 1058, 504, 12, 53, "Text",ExpressionUUID->"06340237-b675-40c8-9d89-adaa184b83c2"],
Cell[CellGroupData[{
Cell[46749, 1074, 856, 15, 30, "Input",ExpressionUUID->"0ca578a4-e09b-48a1-8b42-79c6530ccb68"],
Cell[47608, 1091, 7930, 142, 377, "Output",ExpressionUUID->"10f75ff9-a816-47d7-b644-89f9d47bbe1c"]
}, Open  ]],
Cell[55553, 1236, 463, 8, 53, "Text",ExpressionUUID->"ef313ec0-94c0-487f-92ff-0b13cd95f5ba"],
Cell[CellGroupData[{
Cell[56041, 1248, 858, 15, 30, "Input",ExpressionUUID->"16994a69-855e-46a4-8c08-dcc1717174bd"],
Cell[56902, 1265, 8084, 146, 377, "Output",ExpressionUUID->"25612c1e-003a-4a6a-b00d-a1deb17f5316"]
}, Open  ]],
Cell[65001, 1414, 464, 7, 53, "Text",ExpressionUUID->"c9e87bc3-179d-47d6-b30e-27472427e32b"],
Cell[CellGroupData[{
Cell[65490, 1425, 498, 12, 73, "Input",ExpressionUUID->"54d3b7b1-f963-4635-b992-136ce2d6a325"],
Cell[65991, 1439, 25336, 455, 400, "Output",ExpressionUUID->"8bb5b755-fddf-4a07-939c-b56fada612d6"]
}, Open  ]]
}
]
*)

